@@ -48,8 +48,7 @@ class OpenAPIConverter(FieldConverterMixin):
         Receives the `Schema` class and returns the name to be used in refs within
         the generated spec. When working with circular referencing this function
         must must not return `None` for schemas in a circular reference chain.
-    :param APISpec spec: An initalied spec. Nested schemas will be added to the
-        spec
+    :param APISpec spec: An initialized spec. Nested schemas will be added to the spec
     """
 
     def __init__(
@@ -168,9 +167,9 @@ class OpenAPIConverter(FieldConverterMixin):
                 param["description"] = description
             return [param]
 
-        assert not getattr(
-            schema, "many", False
-        ), "Schemas with many=True are only supported for 'json' location (aka 'in: body')"
+        assert not getattr(schema, "many", False), (
+            "Schemas with many=True are only supported for 'json' location (aka 'in: body')"
+        )
 
         fields = get_fields(schema, exclude_dump_only=True)
 
@@ -219,7 +218,7 @@ class OpenAPIConverter(FieldConverterMixin):
         ret = {}
         partial = getattr(field.parent, "partial", False)
         ret["required"] = field.required and (
-            not partial or (is_collection(partial) and field.name not in partial)  # type:ignore
+            not partial or (is_collection(partial) and field.name not in partial)
         )
         return ret
 
